# BuildGrid Common

🚧 This library is currently WIP and the interfaces might be unstable while the version is `0.0.1-alpha.*`. 🚧

The shared Python Library for the BuildGrid ecosystem.

## Components

### [buildgrid_common.protos](./buildgrid_common/protos/)

Generated proto source files that are compatible with the current BuildGrid service.

### [protogen](./protos/protogen.py)

Utility to generate python source files from protos.

## Contributing

- [CONTRIBUTING](./CONTRIBUTING.md) guide
- [BuildGrid Resources](https://buildgrid.build/index.html#resources)
